@@ -5,7 +5,7 @@ Created on Mon Dec 12 19:24:24 2022
 @author: tjostmou
 """
 
-import os, re, one
+import os, re
 from IPython.display import display
 import pandas as pd, numpy as np
 from . import pattern
